@@ -52,7 +52,7 @@ def test_hdlc_handler_decode_with_flags():
 
 
 def test_hdlc_handler_invalid_state():
-    handler = HDLCHandler(verbose=True)
+    handler = HDLCHandler()
     for byte in b"~test\x42\x42":
         handler.handle_byte(int(byte).to_bytes(1, "little"))
     with pytest.raises(HDLCDecodeException) as exc:
@@ -60,21 +60,17 @@ def test_hdlc_handler_invalid_state():
     assert str(exc.value) == "Incomplete HDLC frame"
 
 
-def test_hdlc_handler_invalid_fcs(capsys):
-    handler = HDLCHandler(verbose=True)
+def test_hdlc_handler_invalid_fcs():
+    handler = HDLCHandler()
     for byte in b"~test\x42\x42~":
         handler.handle_byte(int(byte).to_bytes(1, "little"))
     payload = handler.payload
-    capture = capsys.readouterr()
     assert payload == bytearray()
-    assert capture.out.strip() == "Invalid FCS"
 
 
-def test_hdlc_handler_payload_too_short(capsys):
-    handler = HDLCHandler(verbose=True)
+def test_hdlc_handler_payload_too_short():
+    handler = HDLCHandler()
     for byte in b"~a~":
         handler.handle_byte(int(byte).to_bytes(1, "little"))
     payload = handler.payload
-    capture = capsys.readouterr()
     assert payload == bytearray()
-    assert capture.out.strip() == "Invalid payload"
